@@ -9,13 +9,13 @@
 
 #include <functional>
 #include <memory>
-#include <type_traits>
-#include <unordered_map>
+#include <string>
 #include <fcitx-config/configuration.h>
-#include <fcitx-utils/library.h>
+#include <fcitx-config/rawconfig.h>
+#include <fcitx-utils/macros.h>
 #include <fcitx-utils/metastring.h>
 #include <fcitx/addoninfo.h>
-#include <fcitx/addoninstance_details.h>
+#include <fcitx/addoninstance_details.h> // IWYU pragma: export
 #include "fcitxcore_export.h"
 
 /// \addtogroup FcitxCore
@@ -103,7 +103,8 @@ public:
         return erasureAdaptor->callback(std::forward<Args>(args)...);
     }
     template <typename MetaSignatureString, typename... Args>
-    auto callWithMetaString(Args &&...args) {
+    AddonFunctionSignatureReturnType<MetaSignatureString>
+    callWithMetaString(Args &&...args) {
         return callWithSignature<
             AddonFunctionSignatureType<MetaSignatureString>>(
             MetaSignatureString::data(), std::forward<Args>(args)...);
@@ -111,7 +112,8 @@ public:
 
     /// Call an exported function for this addon.
     template <typename MetaType, typename... Args>
-    auto call(Args &&...args) {
+    AddonFunctionSignatureReturnType<typename MetaType::Name>
+    call(Args &&...args) {
         return callWithSignature<typename MetaType::Signature>(
             MetaType::Name::data(), std::forward<Args>(args)...);
     }
@@ -163,26 +165,29 @@ private:
     namespace fcitx {                                                          \
     template <>                                                                \
     struct AddonFunctionSignature<fcitxMakeMetaString(#NAME "::" #FUNCTION)> { \
-        typedef std::remove_reference_t<decltype(std::declval<SIGNATURE>())>   \
-            type;                                                              \
+        using type =                                                           \
+            std::remove_reference_t<decltype(std::declval<SIGNATURE>())>;      \
     };                                                                         \
     namespace I##NAME {                                                        \
         struct FUNCTION {                                                      \
-            typedef fcitxMakeMetaString(#NAME "::" #FUNCTION) Name;            \
+            using Name = fcitxMakeMetaString(#NAME "::" #FUNCTION);            \
             using Signature = AddonFunctionSignatureType<Name>;                \
         };                                                                     \
     }                                                                          \
     }
 
 #define FCITX_ADDON_EXPORT_FUNCTION(CLASS, FUNCTION)                           \
+    static_assert(std::is_same_v<::fcitx::I##CLASS::FUNCTION::Name,            \
+                                 fcitxMakeMetaString(#CLASS "::" #FUNCTION)>,  \
+                  "");                                                         \
     decltype(::fcitx::MakeAddonFunctionAdaptor(                                \
         &CLASS::FUNCTION)) FUNCTION##Adaptor{#CLASS "::" #FUNCTION, this,      \
                                              &CLASS::FUNCTION};                \
     static_assert(                                                             \
-        std::is_same<decltype(::fcitx::MakeAddonFunctionAdaptor(               \
-                         &CLASS::FUNCTION))::Signature,                        \
-                     ::fcitx::AddonFunctionSignatureType<fcitxMakeMetaString(  \
-                         #CLASS "::" #FUNCTION)>>::value,                      \
+        std::is_same_v<decltype(::fcitx::MakeAddonFunctionAdaptor(             \
+                           &CLASS::FUNCTION))::Signature,                      \
+                       ::fcitx::AddonFunctionSignatureType<                    \
+                           fcitxMakeMetaString(#CLASS "::" #FUNCTION)>>,       \
         "Signature doesn't match");
 
 #define FCITX_ADDON_FACTORY(ClassName)                                         \
